#!/usr/bin/env python3
import random as rand
from multiprocessing import Process, Queue

import click

import lztools.Data.Images
from Resources.Requirements import apt_requires
from lztools.Bash import command_result, command, search_history
from lztools.Data import Text, Images
from lztools.text import search_words, get_random_word

CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])

colorizations = ['none', 'rainbow', 'altbow', 'metal']

def try_read_input(input):
    try:
        return "\n".join(input.readlines())[:-1]
    except:
        return input

@click.group(context_settings=CONTEXT_SETTINGS)
def main():
    """A collection of python tools and bash commands by laz aka nea"""

@main.command(context_settings=CONTEXT_SETTINGS)
@click.argument("term")
@click.option("-r", "--regex", is_flag=True, default=False)
def history(term, regex):
    """Search bash history"""
    for line in search_history(term, regex=regex):
        print(line)

@main.command(context_settings=CONTEXT_SETTINGS)
@click.argument("term", default="")
@click.option('-t', '--type', type=click.Choice(['words', 'images']), help="The type of search")
@click.option("-s", "--strict", is_flag=True, default=False, help="Indicates that letters has to appear in the same order as the do in TERM")
@click.option("-m", "--max-images", default=1, type=click.IntRange(1, 500), help="Max number of images")
def search(term, type, strict, max_images):
    if type == "words":
        res = search_words(term, strict=strict)
        print(res)
    elif type == "images":
        res = lztools.Data.Images.search(term, count=max_images)
        for x in res:
            print(x)

@main.command(context_settings=CONTEXT_SETTINGS)
@click.option('-t', '--type', type=click.Choice(['words', 'images', 'colorization']), default='images', help="Random category")
@click.option("-c", "--count", default=1, help="The number of results")
@click.option("-nn", "--not-nocolor", is_flag=True, default=False, help="Random colorization never selects no color")
@click.argument("input", default=click.get_text_stream('stdin'))
def random(type, count, not_nocolor, input):
    if type == "images":
        res = Images.get_random_image(count=count)
        for x in res:
            print(x)
    elif type == "words":
        for _ in range(count):
            print(get_random_word())
    elif type == "colorization":
        choices = colorizations
        input = try_read_input(input)
        if not_nocolor:
            choices = colorizations[1:]
        color(input, rand.choice(choices), not_nocolor=not_nocolor)

@main.command(context_settings=CONTEXT_SETTINGS)
@click.argument("input", nargs=-1)
@click.option("-d", "--delimiter", nargs=1, help="The delimiter to split the input by")
def split(input, delimiter):
    i = str.join("\n", input).strip()
    if delimiter:
        i = i.split(delimiter)
    else:
        i = i.splitlines()
    for x in i:
        print(x)

@main.command(context_settings=CONTEXT_SETTINGS)
@click.argument("start")
@click.argument("end")
@click.argument("Text", default=click.get_text_stream('stdin'))
@click.option("-p", "--partial-matches", is_flag=True, default=False, help="Used if indicators are not complete lines")
def cut(start, end, text, partial_matches):
    p = False
    for l in text.splitlines():
        if partial_matches:
            if end in l:
                p = False
        else:
            if l == end:
                p = False
        if p:
            print(l)
        if partial_matches:
            if start in l:
                p = True
        else:
            if l == start:
                p = True

@main.command(context_settings=CONTEXT_SETTINGS)
@click.argument("expr")
@click.argument("Text", default=click.get_text_stream('stdin'))
@click.option("-s", "--single-result", is_flag=True, default=False)
def regex(expr, text, single_result):
    input = try_read_input(text)
    print(input, expr)
    if not single_result:
        for x in Text.regex(expr, input, only_first=single_result, suppress=True):
            print(x)
    else:
        print(Text.regex(expr, input, only_first=single_result, suppress=True))

@main.command(context_settings=CONTEXT_SETTINGS)
@click.argument("input")
@click.option('-t', '--type', type=click.Choice(colorizations))
@click.option("-nn", "--not-nocolor", is_flag=True, default=False)
def colorize(input, type, not_nocolor):
    color(input, type, not_nocolor)

@main.command(context_settings=CONTEXT_SETTINGS)
@click.option("-s", "--speed", type=float, default=20)
@click.option("-f", "--frequency", type=float, default=0.1)
@click.option("-a", "--animate", is_flag=True, default=False)
@click.argument("input")
def rainbow(speed, frequency, animate, input):
    args = []
    if animate:
        args.append("-a")
        args.append("--speed")
        args.append(str(speed))

    args.append("--freq")
    args.append(str(frequency))

    command("echo \"{}\" | lolcat {}".format(input, str.join(" ", args)))

def color(input, type, not_nocolor):
    if type == 'none':
        print(input)
    elif type == 'rainbow':
        print(command_result("toilet", "-f", "term", "--gay", input))
    elif type == 'altbow':
        command("echo \"{}\" | lolcat".format(input))
    elif type == 'metal':
        print(command_result("toilet", "-f", "term", "--metal", input))

@main.command(context_settings=CONTEXT_SETTINGS)
@click.option("-w", "--width", type=int, default=100)
@click.option("-i", "--invert", is_flag=True, default=False)
@click.option("-c", "--add-color", is_flag=True, default=False)
@click.argument("target")
def art(width, invert, add_color, target):
    args = []

    if invert:
        args.append("-i")
    if color:
        args.append("-c")

    args.append("--width")
    args.append(str(width))

    args.append(target)
    command("asciiart", *args)

@main.command(context_settings=CONTEXT_SETTINGS)
def install():
    command("sudo apt install -y {}".format(str.join(" ", apt_requires)))

@main.command(context_settings=CONTEXT_SETTINGS)
@click.option('-o', '--operation', type=click.Choice(["bashrc", "autosource"]))
def bash(operation):

    pass

def to_art(q, url, width, c=False):
    args = ["art", url, f"-w {str(width-2)}"]
    if c:
        args.append("-c")
    q.put(command_result("lztools", *args))


# @main.command(context_settings=CONTEXT_SETTINGS)
# @click.option("-n", "--noire", is_flag=True, default=False)
# def fun(noire):
#     active = None
#     q = Queue()
#     res = command_result("tput", "cols")
#     for i in Images.get_random_image(count=300):
#         p = Process(target=to_art, args=(q, i, noire))
#         p.st
#     for img in :
#         if active != None:
#             if not noire:
#                 command(f"lztools rainbow \"$(lztools art {img} -w {int(res)-2})\" -a -s 500")
#             else:
#                 command(f"lztools art {img} -w {int(res)-2} -c")
#         Process(target=)



# def to_art(q, url, c=False):
#     ctext = f"lztools art {img} -w {int(res)-2}"
#     if c:
#         ctext += " -c"
#     q.put(command_result(ctext))


@main.command(context_settings=CONTEXT_SETTINGS)
@click.option("-n", "--noire", is_flag=True, default=False)
def fun(noire):
    q = Queue()
    res = int(command_result("tput", "cols"))
    ps = []

    for i in Images.get_random_image(count=300):
        p = Process(target=to_art, args=(q, i, res, noire))
        p.start()
        ps.append(p)
    while True:
        try:
            print(q.get())
        except:
            break

if __name__ == '__main__':
    main()




# @main.command(context_settings=CONTEXT_SETTINGS)
# @click.option("-r", "--random", "operation", default=False, flag_value="random")
# @click.option("-s", "--strict", "operation", default=False, flag_value="strict")
# @click.option("-d", "--division", "operation", default=False, flag_value="division")
# @click.option("-fr", "--find-regex", "operation", default=False, flag_value="regex")
# @click.option("-f", "--find", "operation", default=True, flag_value="search")
# @click.argument("search", nargs=-1)
# def text(operation, search):
#     print(operation, search)
#     exit()
#     """Get or generate text"""
#     if operation == "random":
#         pass
#     elif operation == "strict":
#         pass
#     elif operation == "division":
#         pass
#     elif operation == "regex":
#         pass
#     elif operation == "search":
#         ss = search.split(search)
#         for part in ss:
#             if part is not None and part != "":
#                 print(part)
#     elif operation == "random" and search == "":
#     else:
#         res = search_words(search, strict=strict)
#         if random:
#             print(rand.choice(list(res)))
#         else:
#             for w in res:
#                 print(w)

# @main.command(context_settings=CONTEXT_SETTINGS)
# @click.argument("PATH")
# @click.option("-c/-m", "--color/--monochrome", default=False)
# @click.option("-w", "--width", default=100, type=click.IntRange(1, 500))
# @click.option("-i", "--invert", is_flag=True, default=False)
# def art(path, color, width, invert):
#     """fun"""
#     args = ["--width", str(width), path]
#     if color:
#         args.append("-c")
#     if invert:
#         args.append("-i")
#     command = ["asciiart", *args]
#     print("Command: {}".format(command))
#     print(subprocess.check_call(command))




# @main.command(context_settings=CONTEXT_SETTINGS)
# @click.option('--data-type', type=click.Choice(['picture', 'text']), default='picture', help="The data type to work with")
# def data(data_type):
#     """Get or generate data"""
#     if data_type == 'picture':
#         print("pic {}".format(data_type))
#     elif data_type == 'text':
#         print("text {}".format(data_type))
#     else:
#         print("Invalid argument (--data-type = {})".format(data_type))






import sys

import Ansi

def add_stdin_arg(name, parser):
    parser.add_argument(name, nargs="*", default=sys.stdin, type=str)

def parse_stdin_arg(value):
    prep = (lambda x: x[:-1]) if type(value).__name__ == "file" else (lambda x: x)
    return (Ansi.strip_reg(prep(x)) for x in value)


import os
from pathlib import Path
from subprocess import run

from lztools import text

def command_result(name, *args):
    try:
        result = run([name, *args], capture_output=True, universal_newlines=True, check=True)
        # x = check_output([name, *args], universal_newlines=True)
        #
        # Popen()
        return result.stdout
    except:
        raise

# def command(command):
#     os.system(command)

def command(command, *args):
    fargs = " ".join(args)
    os.system(f"{command} {fargs}")

def apt_install(package):
    command(f"sudo apt install -y {package}")


def get_history():
    return command_result("cat", "{}/.bash_history".format(str(Path.home())))

def search_history(term, regex=False):
    if not regex:
        for line in get_history().splitlines():
            if term in line:
                yield line
    else:
        return text.regex(term, get_history())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import subprocess

import pip

from lztools.Data.Text import regex
from lztools.Managers.TempPath import TempPath

def extract_module_version(text):
    return regex(" \d+\.\d+\.\d+", text, only_first=True)[1:]

def local_install(path, upload=False):
    output_func = _upload if upload else None
    _install(path, output_func)

def _upload(path):
    online = get_version_online(os.path.basename(path))
    local = get_version(path)
    if online == local:
        raise Exception("Error: Same version as online")
    else:
        subprocess.call(["twine", "upload", "dist/*"])

def _install(path, output_func=None):
    with TempPath(path) as rp:
        subprocess.call(["rm", "-rf", "dist"])
        subprocess.call(["python", "setup.py", "install"])
        e = None
        if output_func is not None:
            try:
                output_func(rp)
            except Exception as e:
                pass

        subprocess.call(["rm", "-rf", "build"])
        subprocess.call(["rm", "-rf", "dist"])
        subprocess.call(["rm", "-rf", "*.egg-info"])
        if e is not None:
            raise e

def get_version_online(name):
    out = subprocess.check_output(["python", "-m", "pip", "show", "-V", name])
    return extract_module_version(out).rstrip("\n")

def get_version(path):
    with TempPath(path) as rp:
        return subprocess.check_output(["python", "setup.py", "-V"]).rstrip("\n")

def pip_install(package):
    pip.main(['install', package])






from lztools.Bash import command_result
from lztools.DataTypes.DockerData import DockerData

def get_running():
    res = command_result("sudo", "docker", "ps", "-a", u"--format '{{.ID}}*{{.Image}}*{{.Command}}*{{.CreatedAt}}*{{.RunningFor}}*{{.Ports}}*{{.Status}}*{{.Size}}*{{.Names}}*{{.Labels}}*{{.Mounts}}*{{.Networks}}'")

    for d in res[1].splitlines():
        yield DockerData(d, delimiter="*")



import click

CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])

@click.group(context_settings=CONTEXT_SETTINGS)
def main():
    """lztools for git"""

@main.command(context_settings=CONTEXT_SETTINGS)
def branch():
    """Branch operations"""


import inspect
import sys
import warnings

import gc
from inspect import getfile

import zope.proxy

class LazyVariable(object):

    def __init__(self, specifier):
        self.specifier = specifier

    def get(self):
        return self.specifier()

class DeferredAndDeprecated(LazyVariable):

    def __init__(self, specifier, message):
        super(DeferredAndDeprecated, self).__init__(specifier)
        self.message = message

    def get(self):
        warnings.warn(
            self.__name__ + " is deprecated. " + self.message,
            DeprecationWarning, stacklevel=3)

        return super(DeferredAndDeprecated, self).get()

class ModuleProxy(zope.proxy.ProxyBase):
    __slots__ = ('__deferred_definitions__', '__doc__')

    def __init__(self, module):
        super(ModuleProxy, self).__init__(module)
        self.__deferred_definitions__ = {}
        self.__doc__ = module.__doc__

    def __getattr__(self, name):
        try:
            get = self.__deferred_definitions__.pop(name)
        except KeyError:
            raise AttributeError(name)
        v = get.get()
        setattr(self, name, v)
        return v

def initialize(level=1):
    """Prepare a module to support deferred imports.

    Modules do not need to call this directly, because the
    `define*` and `deprecated*` functions call it.

    This is intended to be called from the module to be prepared.
    The implementation wraps a proxy around the module and replaces
    the entry in sys.modules with the proxy.  It does no harm to
    call this function more than once for a given module, because
    this function does not re-wrap a proxied module.

    The level parameter specifies a relative stack depth.
    When this function is called directly by the module, level should be 1.
    When this function is called by a helper function, level should
    increase with the depth of the stack.

    Returns nothing when level is 1; otherwise returns the proxied module.
    """
    __name__ = sys._getframe(level).f_globals['__name__']
    module = sys.modules[__name__]
    if type(module) is not ModuleProxy:
        module = ModuleProxy(module)
        sys.modules[__name__] = module

    if level == 1:
        return
    return module

def get_variable_name():
    f = inspect.currentframe().f_back.f_back
    filename = getfile(f)
    code_line = open(filename).readlines()[f.f_lineno - 1]
    assigned_variable = code_line.split("=")[0].strip()
    return assigned_variable

def find_names(self):
    frame = inspect.currentframe()
    for frame in iter(lambda: frame.f_back, None):
        frame.f_locals
    obj_names = []
    for referrer in gc.get_referrers(self):
        if isinstance(referrer, dict):
            for k, v in referrer.items():
                if v is self:
                    obj_names.append(k)
    print(obj_names)

def define(name, func):
    module = initialize(2)
    # name = get_variable_name()
    __deferred_definitions__ = module.__deferred_definitions__
    __deferred_definitions__[name] = LazyVariable(func)

def defineFrom(from_name, *names):
    """Define deferred imports from a particular module.

    The from_name specifies which module to import.
    The rest of the parameters specify names to import from that module.
    """
    module = initialize(2)
    __deferred_definitions__ = module.__deferred_definitions__
    for name in names:
        specifier = from_name + ':' + name
        __deferred_definitions__[name] = LazyVariable(specifier)

def deprecated(message, **names):
    """Define deferred and deprecated imports using keyword parameters.

    The first use of each name will generate a deprecation warning with
    the given message.

    Each parameter specifies the importable name and how to import it.
    Use `module:name` syntax to import a name from a module, or `module`
    (no colon) to import a module.
    """
    module = initialize(2)
    __deferred_definitions__ = module.__deferred_definitions__
    for name, specifier in names.items():
        __deferred_definitions__[name] = DeferredAndDeprecated(specifier, message)

def deprecatedFrom(message, from_name, *names):
    """Define deferred and deprecated imports from a particular module.

    The first use of each name will generate a deprecation warning with
    the given message.

    The from_name specifies which module to import.
    The rest of the parameters specify names to import from that module.
    """
    module = initialize(2)
    __deferred_definitions__ = module.__deferred_definitions__
    for name in names:
        specifier = from_name + ':' + name
        __deferred_definitions__[name] = DeferredAndDeprecated(specifier, message)



import click
from lztools.text import regex

CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])

@click.command(context_settings=CONTEXT_SETTINGS)
@click.argument("expr")
@click.argument("text", default=click.get_text_stream('stdin'))
@click.option("-s", "--single-result", is_flag=True, default=False)
def main(expr, text, single_result):
    """Regex using python"""
    for res in regex(expr, text):
        print(res)
        if single_result:
            break


import os

import time

class TempPath(object):
    time = None

    def __enter__(self):
        self.time = time.time()
        return self.time

    def __exit__(self, exc_type, exc_val, exc_tb):
        os.chdir(self.original_path)



import os

class TempPath(object):
    original_path = None
    new_path = None

    def __init__(self, path):
        self.original_path = os.getcwd()
        self.new_path = os.path.realpath(path)

    def __enter__(self):
        os.chdir(self.new_path)
        return self.new_path

    def __exit__(self, exc_type, exc_val, exc_tb):
        os.chdir(self.original_path)



dprops = [
    "ID",
    "Image",
    "Command",
    "CreatedAt",
    "RunningFor",
    "Ports",
    "Status",
    "Size",
    "Names",
    "Labels",
    "Mounts",
    "Networks"
]
class DockerData(object):
    def __init__(self, init_str, delimiter="¤"):
        for i, v in enumerate(init_str.split(delimiter)):
            setattr(self, property(dprops[i], v))




import sys
from functools import partial

import zope.proxy

def super_property(func):
    def executor(f, key):
        return f()
    class _M(object):
        y = property(partial(executor, func))
    _m = _M()
    return _m.y

class LazyVariable(object):
    value = None
    value_loaded = False


    def __init__(self, specifier):
        self.specifier = specifier

    def get(self):
        if not self.value_loaded:
            self.value = self.specifier()
            self.value_loaded = True
        return self.value

class ModuleProxy(zope.proxy.ProxyBase):
    __slots__ = ('__deferred_definitions__', '__doc__')

    def __init__(self, module):
        super(ModuleProxy, self).__init__(module)
        self.__deferred_definitions__ = {}
        self.__doc__ = module.__doc__

    def __getattr__(self, name):
        try:
            get = self.__deferred_definitions__.pop(name)
        except KeyError:
            raise AttributeError(name)
        v = get.get()
        setattr(self, name, v)
        return v

def initialize(level=1):
    """Prepare a module to support deferred imports.

    Modules do not need to call this directly, because the
    `define*` and `deprecated*` functions call it.

    This is intended to be called from the module to be prepared.
    The implementation wraps a proxy around the module and replaces
    the entry in sys.modules with the proxy.  It does no harm to
    call this function more than once for a given module, because
    this function does not re-wrap a proxied module.

    The level parameter specifies a relative stack depth.
    When this function is called directly by the module, level should be 1.
    When this function is called by a helper function, level should
    increase with the depth of the stack.

    Returns nothing when level is 1; otherwise returns the proxied module.
    """
    __name__ = sys._getframe(level).f_globals['__name__']
    module = sys.modules[__name__]
    if type(module) is not ModuleProxy:
        module = ModuleProxy(module)
        sys.modules[__name__] = module

    if level == 1:
        return
    return module

def define(name, func):
    module = initialize(2)
    # name = get_variable_name()
    __deferred_definitions__ = module.__deferred_definitions__
    print(module.__name__)
    print(dir(module))
#    sys.modules[""]
    __deferred_definitions__[name] = LazyVariable(func)

#
# class DeferredAndDeprecated(LazyVariable):
#
#     def __init__(self, specifier, message):
#         super(DeferredAndDeprecated, self).__init__(specifier)
#         self.message = message
#
#     def get(self):
#         warnings.warn(
#             self.__name__ + " is deprecated. " + self.message,
#             DeprecationWarning, stacklevel=3)
#
#         return super(DeferredAndDeprecated, self).get()

# def defineFrom(from_name, *names):
#     """Define deferred imports from a particular module.
#
#     The from_name specifies which module to import.
#     The rest of the parameters specify names to import from that module.
#     """
#     module = initialize(2)
#     __deferred_definitions__ = module.__deferred_definitions__
#     for name in names:
#         specifier = from_name + ':' + name
#         __deferred_definitions__[name] = LazyVariable(specifier)

# def deprecated(message, **names):
#     """Define deferred and deprecated imports using keyword parameters.
#
#     The first use of each name will generate a deprecation warning with
#     the given message.
#
#     Each parameter specifies the importable name and how to import it.
#     Use `module:name` syntax to import a name from a module, or `module`
#     (no colon) to import a module.
#     """
#     module = initialize(2)
#     __deferred_definitions__ = module.__deferred_definitions__
#     for name, specifier in names.items():
#         __deferred_definitions__[name] = DeferredAndDeprecated(specifier, message)

# def deprecatedFrom(message, from_name, *names):
#     """Define deferred and deprecated imports from a particular module.
#
#     The first use of each name will generate a deprecation warning with
#     the given message.
#
#     The from_name specifies which module to import.
#     The rest of the parameters specify names to import from that module.
#     """
#     module = initialize(2)
#     __deferred_definitions__ = module.__deferred_definitions__
#     for name in names:
#         specifier = from_name + ':' + name
#         __deferred_definitions__[name] = DeferredAndDeprecated(specifier, message)



import inspect
import gc

import time
from sys import maxsize

def get_variable_name():
    f = inspect.currentframe().f_back.f_back
    filename = inspect.getfile(f)
    code_line = open(filename).readlines()[f.f_lineno - 1]
    assigned_variable = code_line.split("=")[0].strip()
    return assigned_variable

def find_names(self):
    frame = inspect.currentframe()
    for frame in iter(lambda: frame.f_back, None):
        frame.f_locals
    obj_names = []
    for referrer in gc.get_referrers(self):
        if isinstance(referrer, dict):
            for k, v in referrer.items():
                if v is self:
                    obj_names.append(k)
    print(obj_names)

def _time_operation(func):
    t1 = time.time()
    func()
    return time.time() - t1

def time_operation(func, count, id=None):
    if id is None:
        id=""
    else:
        id = "{}: ".format(id)
    total = 0
    min = maxsize
    max = 0
    for i in range(1, count+1):
        t = _time_operation(func)
        total += t
        if t > max:
            max = t
        if t < min:
            min = t
        average = total / i
        if i % 50 == 0:
            print("{}#{}: Average: {}\tMin: {}\tMax: {}".format(id, i, average, min, max))


#!/usr/bin/env python3
import os

import click

from lztools.Bash import command_result
from lztools.text import regex

CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])

@click.group(context_settings=CONTEXT_SETTINGS)
def main():
    """A collection of python tools and bash commands for git by Laz aka nea"""
    pass

@main.command(context_settings=CONTEXT_SETTINGS)
@click.option("-a" "--all", is_flag=True, default=True)
def kill():
    """test"""
    pass

@main.command(context_settings=CONTEXT_SETTINGS)
@click.option("-p", "--path", default=".")
def branch(path):
    """Gets the active branch"""
    print(os.getcwd())
    for x in regex(r"\* (.*)", command_result("git", "branch")[1]):
        print(x)

if __name__ == '__main__':
    main()



#!/usr/bin/env python3
import argparse
from functools import partial
from types import GeneratorType

import flickrapi

def auth():
    return flickrapi.FlickrAPI("2a41e37e58cd08c0dbd5af131441dca0", "72c6a92f49f48f9e", format="parsed-json")

def add_total(img):
    img["total"] = int(img["width"])+int(img["height"])
    return img

def handle_args():
    global args
    parser = argparse.ArgumentParser()
    parser.add_argument("-v", "--verbose", default=False, action='store_true', required=False)
    args = parser.parse_args()
    return args

def search(term, count=1, verbose=False):
    photos = auth().photos_search(text=term, safe_search=3, per_page=count, extras="url_sq, url_t, url_s, url_q, url_m, url_n, url_z, url_c, url_l, url_o")["photos"]["photo"]
    return map(partial(get_output, verbose=verbose), photos)

def get_random_image(verbose=False, count=1):
    photos = auth().photos.getRecent(per_page=count, extras="url_sq, url_t, url_s, url_q, url_m, url_n, url_z, url_c, url_l, url_o")["photos"]["photo"]
    return map(partial(get_output, verbose=verbose), photos)

def get_outputs(images, verbose):
    for x in images:
        if isinstance(x, GeneratorType):
            for y in x:
                yield get_output(y, verbose)
        else:
            yield get_output(x, verbose)

def get_output(image, verbose=False):
    if verbose:
        return u"Title: {}\nUrl: {}".format(image["title"], image["url_o"])
    else:
        try:
            return image["url_o"]
        except:
            for k in image:
                if k.startswith("url") and image[k][-6] != "_":
                    return image[k]



#!/usr/bin/env python3
import codecs
import os
import subprocess

import sys
from setuptools import setup

from Resources.Requirements import pip_requires

try:
    codecs.lookup('mbcs')
except LookupError:
    ascii = codecs.lookup('ascii')
    func = lambda name, enc=ascii: {True: enc}.get(name=='mbcs')
    codecs.register(func)

# print(os.getcwd())
# subprocess.run(["./Commands/link-commands", "-f"])

setup(
    name='lztools',
    author='Laz aka Zanzes',
    author_email='ubuntuea@gmail.com',
    version='1.1.11 ',
    license='MIT License',
    description='A collection of useful utilities by Laz aka Zanzes',
    url='',
    entry_points={
        'console_scripts': [
            'lztools = cli.lztools:main',
            'preg = cli.preg:main',
            'lmod = cli.lmod:main',
            'ldoc = cli.ldock:main',
            'lgit = cli.lgit:main'
        ],
    },
    install_requires=pip_requires,
    packages=['lztools', 'cli', 'lztools.Managers', 'lztools.DataTypes', 'lztools.Data', 'lztools.Junk', 'Resources'],
    zip_safe=False,
    classifiers=[  # Optional
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: System :: Systems Administration',

        # Pick your license as you wish
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.7',
    ],
)




import re

def regex(expr, text, only_first=False, suppress=False):
    if only_first:
        if suppress:
            try:
                return re.search(expr, text).group(0)
            except:
                pass
        else:
            return re.search(expr, text).group(0)
    else:
        return (x for x in re.findall(expr, text))



#!/usr/bin/env python3

import click

CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])

@click.group(context_settings=CONTEXT_SETTINGS)
def main():
    """A collection of python tools and bash commands for manipulating text by laz aka nea"""
    pass

if __name__ == '__main__':
    main()
